@@ -42,7 +42,7 @@ use base qw /Petal::Canonicalizer::XML/;
 # link
 # meta
 # param
-# ---#8---
+# --->8---
 # 
 # [1] http://www.w3.org/TR/html401/index/elements.html
 
@@ -69,7 +69,7 @@ sub StartTag
     return if ($class->_is_inside_content_or_replace());
     
     my $tag = $_;
-    ($tag) = $tag =~ /^<\s*((?:\w|:)*)/;
+    ($tag) = $tag =~ /^<\s*((?:\w|\:|\-)*)/;
     my $att = { %_ };
 
     $class->_on_error ($tag, $att);
@@ -205,7 +205,7 @@ sub EndTag
 {
     my $class = shift;
     return if ($class->_is_inside_content_or_replace ( 'endtag' ));
-    my ($tag) = $_ =~ /^<\/\s*((?:\w|:)*)/;
+    my ($tag) = $_ =~ /^<\/\s*((?:\w|\:|\-)*)/;
     my $node = pop (@Petal::Canonicalizer::XML::NodeStack);
     
     return if ($class->_is_xinclude ($tag));
